<?php
namespace AIOSEO\Plugin\Addon\Redirects\ImportExport;

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Imports the settings and meta data from other plugins.
 *
 * @since 1.0.0
 */
class Importer {
	/**
	 * A list of supported HTTP status codes.
	 *
	 * @since 1.0.0
	 *
	 * @var array
	 */
	private $supportedStatusCodes = [
		301,
		302,
		303,
		304,
		307,
		308
	];

	/**
	 * The post action name.
	 *
	 * @since 1.0.0
	 *
	 * @param ImportExport $importer The main importer class.
	 */
	public function __construct( $importer ) {
		$plugins = $this->plugins;
		foreach ( $plugins as $key => $plugin ) {
			$plugins[ $key ]['class'] = $this;
		}
		$importer->addPlugins( $plugins );
	}

	/**
	 * Undocumented function
	 *
	 * @param  mixed   $code The code to validate.
	 * @return boolean       True if the code validates.
	 */
	protected function validateStatusCode( $code ) {
		if ( is_string( $code ) ) {
			if ( ! preg_match( '/\A\d+\Z/', $code, $matches ) ) {
				return false;
			}
			$code = (int) $code;
		}

		return in_array( $code, $this->supportedStatusCodes, true );
	}
}